==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/Thumbnail.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.StreamProvider;
import com.github.davidmoten.odata.client.StreamUploader;
import com.github.davidmoten.odata.client.StreamUploaderChunked;
import com.github.davidmoten.odata.client.StreamUploaderSingleCall;
import com.github.davidmoten.odata.client.UploadStrategy;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "content", 
    "height", 
    "sourceItemId", 
    "url", 
    "width"})
@JsonInclude(Include.NON_NULL)
public class Thumbnail implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("content")
    protected String content;

    @JsonProperty("height")
    protected Integer height;

    @JsonProperty("sourceItemId")
    protected String sourceItemId;

    @JsonProperty("url")
    protected String url;

    @JsonProperty("width")
    protected Integer width;

    protected Thumbnail() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.thumbnail";
    }

    @Property(name="content")
    @JsonIgnore
    public Optional<StreamProvider> getContent() {
        return RequestHelper.createStreamForEdmStream(contextPath, this, "content", content);
    }

    /**
     * If metadata indicate that the stream is editable then returns
     * a {@link StreamUploader} which can be used to upload the stream
     * to the {@code content} property.
     *
     * @return a StreamUploader if upload permitted
     */
    @Property(name="content")
    public Optional<StreamUploaderSingleCall> putContent() {
        return putContent(UploadStrategy.singleCall());
    }

    /**
     * If metadata indicate that the stream is editable then returns
     * a {@link StreamUploaderChunked} which can be used to upload the stream
     * to the {@code content} property.
     *
     * @return a StreamUploaderChunked if upload permitted
     */
    @Property(name="content")
    public Optional<StreamUploaderChunked> putChunkedContent() {
        return putContent(UploadStrategy.chunked());
    }

    @Property(name="content")
    public <T extends StreamUploader<T>> Optional<T> putContent(UploadStrategy<T> strategy) {
        return strategy.builder(contextPath.addSegment("content"), this, "content");
    }

    @Property(name="height")
    @JsonIgnore
    public Optional<Integer> getHeight() {
        return Optional.ofNullable(height);
    }

    public Thumbnail withHeight(Integer height) {
        Thumbnail _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.thumbnail");
        _x.height = height;
        return _x;
    }

    @Property(name="sourceItemId")
    @JsonIgnore
    public Optional<String> getSourceItemId() {
        return Optional.ofNullable(sourceItemId);
    }

    public Thumbnail withSourceItemId(String sourceItemId) {
        Thumbnail _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.thumbnail");
        _x.sourceItemId = sourceItemId;
        return _x;
    }

    @Property(name="url")
    @JsonIgnore
    public Optional<String> getUrl() {
        return Optional.ofNullable(url);
    }

    public Thumbnail withUrl(String url) {
        Thumbnail _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.thumbnail");
        _x.url = url;
        return _x;
    }

    @Property(name="width")
    @JsonIgnore
    public Optional<Integer> getWidth() {
        return Optional.ofNullable(width);
    }

    public Thumbnail withWidth(Integer width) {
        Thumbnail _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.thumbnail");
        _x.width = width;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String content;
        private Integer height;
        private String sourceItemId;
        private String url;
        private Integer width;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder content(String content) {
            this.content = content;
            this.changedFields = changedFields.add("content");
            return this;
        }

        public Builder height(Integer height) {
            this.height = height;
            this.changedFields = changedFields.add("height");
            return this;
        }

        public Builder sourceItemId(String sourceItemId) {
            this.sourceItemId = sourceItemId;
            this.changedFields = changedFields.add("sourceItemId");
            return this;
        }

        public Builder url(String url) {
            this.url = url;
            this.changedFields = changedFields.add("url");
            return this;
        }

        public Builder width(Integer width) {
            this.width = width;
            this.changedFields = changedFields.add("width");
            return this;
        }

        public Thumbnail build() {
            Thumbnail _x = new Thumbnail();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.thumbnail";
            _x.content = content;
            _x.height = height;
            _x.sourceItemId = sourceItemId;
            _x.url = url;
            _x.width = width;
            return _x;
        }
    }

    private Thumbnail _copy() {
        Thumbnail _x = new Thumbnail();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.content = content;
        _x.height = height;
        _x.sourceItemId = sourceItemId;
        _x.url = url;
        _x.width = width;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("Thumbnail[");
        b.append("content=");
        b.append(this.content);
        b.append(", ");
        b.append("height=");
        b.append(this.height);
        b.append(", ");
        b.append("sourceItemId=");
        b.append(this.sourceItemId);
        b.append(", ");
        b.append("url=");
        b.append(this.url);
        b.append(", ");
        b.append("width=");
        b.append(this.width);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/complex/Thumbnail.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.HttpMethod;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.StreamProvider;
import com.github.davidmoten.odata.client.StreamUploader;
import com.github.davidmoten.odata.client.StreamUploaderChunked;
import com.github.davidmoten.odata.client.StreamUploaderSingleCall;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.UploadStrategy;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Integer;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "content", 
    "height", 
    "sourceItemId", 
    "url", 
    "width"})
@JsonInclude(Include.NON_NULL)
public class Thumbnail implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("content")
    protected String content;

    @JsonProperty("height")
    protected Integer height;

    @JsonProperty("sourceItemId")
    protected String sourceItemId;

    @JsonProperty("url")
    protected String url;

    @JsonProperty("width")
    protected Integer width;

    protected Thumbnail() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.thumbnail";
    }

    @Property(name="content")
    @JsonIgnore
    public Optional<StreamProvider> getContent() {
        return RequestHelper.createStreamForEdmStream(contextPath, this, "content", content);
    }

    /**
     * If metadata indicate that the stream is editable then returns
     * a {@link StreamUploader} which can be used to upload the stream
     * to the {@code content} property, using HTTP POST.
     *
     * @return a StreamUploader if upload permitted
     */
    @Property(name="content")
    public Optional<StreamUploaderSingleCall> postContent() {
        return postContent(UploadStrategy.singleCall());
    }

    /**
     * If metadata indicate that the stream is editable then returns
     * a {@link StreamUploaderChunked} which can be used to upload the stream
     * to the {@code content} property, using HTTP POST.
     *
     * @return a StreamUploaderChunked if upload permitted
     */
    @Property(name="content")
    public Optional<StreamUploaderChunked> postChunkedContent() {
        return postContent(UploadStrategy.chunked());
    }

    @Property(name="content")
    public <T extends StreamUploader<T>> Optional<T> postContent(UploadStrategy<T> strategy) {
        return strategy.builder(contextPath.addSegment("content"), this, "content", HttpMethod.POST);
    }

    /**
     * If metadata indicate that the stream is editable then returns
     * a {@link StreamUploader} which can be used to upload the stream
     * to the {@code content} property, using HTTP PATCH.
     *
     * @return a StreamUploader if upload permitted
     */
    @Property(name="content")
    public Optional<StreamUploaderSingleCall> patchContent() {
        return patchContent(UploadStrategy.singleCall());
    }

    /**
     * If metadata indicate that the stream is editable then returns
     * a {@link StreamUploaderChunked} which can be used to upload the stream
     * to the {@code content} property, using HTTP PATCH.
     *
     * @return a StreamUploaderChunked if upload permitted
     */
    @Property(name="content")
    public Optional<StreamUploaderChunked> patchChunkedContent() {
        return patchContent(UploadStrategy.chunked());
    }

    @Property(name="content")
    public <T extends StreamUploader<T>> Optional<T> patchContent(UploadStrategy<T> strategy) {
        return strategy.builder(contextPath.addSegment("content"), this, "content", HttpMethod.PATCH);
    }

    /**
     * If metadata indicate that the stream is editable then returns
     * a {@link StreamUploader} which can be used to upload the stream
     * to the {@code content} property, using HTTP PUT.
     *
     * @return a StreamUploader if upload permitted
     */
    @Property(name="content")
    public Optional<StreamUploaderSingleCall> putContent() {
        return putContent(UploadStrategy.singleCall());
    }

    /**
     * If metadata indicate that the stream is editable then returns
     * a {@link StreamUploaderChunked} which can be used to upload the stream
     * to the {@code content} property, using HTTP PUT.
     *
     * @return a StreamUploaderChunked if upload permitted
     */
    @Property(name="content")
    public Optional<StreamUploaderChunked> putChunkedContent() {
        return putContent(UploadStrategy.chunked());
    }

    @Property(name="content")
    public <T extends StreamUploader<T>> Optional<T> putContent(UploadStrategy<T> strategy) {
        return strategy.builder(contextPath.addSegment("content"), this, "content", HttpMethod.PUT);
    }

    @Property(name="height")
    @JsonIgnore
    public Optional<Integer> getHeight() {
        return Optional.ofNullable(height);
    }

    public Thumbnail withHeight(Integer height) {
        Thumbnail _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.thumbnail");
        _x.height = height;
        return _x;
    }

    @Property(name="sourceItemId")
    @JsonIgnore
    public Optional<String> getSourceItemId() {
        return Optional.ofNullable(sourceItemId);
    }

    public Thumbnail withSourceItemId(String sourceItemId) {
        Thumbnail _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.thumbnail");
        _x.sourceItemId = sourceItemId;
        return _x;
    }

    @Property(name="url")
    @JsonIgnore
    public Optional<String> getUrl() {
        return Optional.ofNullable(url);
    }

    public Thumbnail withUrl(String url) {
        Thumbnail _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.thumbnail");
        _x.url = url;
        return _x;
    }

    @Property(name="width")
    @JsonIgnore
    public Optional<Integer> getWidth() {
        return Optional.ofNullable(width);
    }

    public Thumbnail withWidth(Integer width) {
        Thumbnail _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.thumbnail");
        _x.width = width;
        return _x;
    }

    public Thumbnail withUnmappedField(String name, Object value) {
        Thumbnail _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String content;
        private Integer height;
        private String sourceItemId;
        private String url;
        private Integer width;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder content(String content) {
            this.content = content;
            this.changedFields = changedFields.add("content");
            return this;
        }

        public Builder height(Integer height) {
            this.height = height;
            this.changedFields = changedFields.add("height");
            return this;
        }

        public Builder sourceItemId(String sourceItemId) {
            this.sourceItemId = sourceItemId;
            this.changedFields = changedFields.add("sourceItemId");
            return this;
        }

        public Builder url(String url) {
            this.url = url;
            this.changedFields = changedFields.add("url");
            return this;
        }

        public Builder width(Integer width) {
            this.width = width;
            this.changedFields = changedFields.add("width");
            return this;
        }

        public Thumbnail build() {
            Thumbnail _x = new Thumbnail();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.thumbnail";
            _x.content = content;
            _x.height = height;
            _x.sourceItemId = sourceItemId;
            _x.url = url;
            _x.width = width;
            return _x;
        }
    }

    private Thumbnail _copy() {
        Thumbnail _x = new Thumbnail();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.content = content;
        _x.height = height;
        _x.sourceItemId = sourceItemId;
        _x.url = url;
        _x.width = width;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("Thumbnail[");
        b.append("content=");
        b.append(this.content);
        b.append(", ");
        b.append("height=");
        b.append(this.height);
        b.append(", ");
        b.append("sourceItemId=");
        b.append(this.sourceItemId);
        b.append(", ");
        b.append("url=");
        b.append(this.url);
        b.append(", ");
        b.append("width=");
        b.append(this.width);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
